@@ -28,6 +28,16 @@
 #include <libgearman-1.0/interface/status.h>
 #include <libgearman-1.0/status.h>
 
+zend_class_entry *gearman_exception_ce;
+zend_class_entry *gearman_client_ce;
+zend_object_handlers gearman_client_obj_handlers;
+zend_class_entry *gearman_task_ce;
+zend_object_handlers gearman_task_obj_handlers;
+zend_class_entry *gearman_job_ce;
+zend_object_handlers gearman_job_obj_handlers;
+zend_class_entry *gearman_worker_ce;
+zend_object_handlers gearman_worker_obj_handlers;
+
 
 /* {{{ arginfo */
 ZEND_BEGIN_ARG_INFO_EX(arginfo_gearman_version, 0, 0, 0)
@@ -681,13 +691,11 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_oo_gearman_client_set_context, 0, 0, 1)
 	ZEND_ARG_INFO(0, context)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_gearman_client_run_tasks, 0, 0, 2)
+ZEND_BEGIN_ARG_INFO_EX(arginfo_gearman_client_run_tasks, 0, 0, 1)
 	ZEND_ARG_INFO(0, client_object)
-	ZEND_ARG_INFO(0, data)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_oo_gearman_client_run_tasks, 0, 0, 1)
-	ZEND_ARG_INFO(0, data)
+ZEND_BEGIN_ARG_INFO_EX(arginfo_oo_gearman_client_run_tasks, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
 /*
