@@ -24,7 +24,7 @@
 #include <libgearman-1.0/status.h>
 
 /* module version */
-#define PHP_GEARMAN_VERSION "2.0.2"
+#define PHP_GEARMAN_VERSION "2.0.3"
 
 extern zend_module_entry gearman_module_entry;
 #define phpext_gearman_ptr &gearman_module_entry
@@ -33,7 +33,7 @@ typedef enum {
         GEARMAN_OBJ_CREATED = (1 << 0)
 } gearman_obj_flags_t;
 
-zend_class_entry *gearman_exception_ce;
+extern zend_class_entry *gearman_exception_ce;
 
 #define GEARMAN_EXCEPTION(__error, __error_code) { \
         zend_throw_exception(gearman_exception_ce, __error, __error_code); \
